@@ -43,6 +43,8 @@ struct _CmpackFitsFile
 	char *buffer;
 	size_t bufsize;
 	CmpackBitpix bitpix;
+	CmpackOpenMode mode;
+	unsigned flags;
 };
 typedef struct _CmpackFitsFile CmpackFitsFile;
 
@@ -447,16 +449,16 @@ int fits_test(const char *block, size_t length, size_t filesize)
 }
 
 /* Open a FITS file */
-int fits_open(tHandle *handle, const char *filename, CmpackOpenMode flags)
+int fits_open(tHandle *handle, const char *filename, CmpackOpenMode mode, unsigned flags)
 {
 	int readonly, imgtype;
 
 	CmpackFitsFile *fs = (CmpackFitsFile*)cmpack_calloc(1, sizeof(CmpackFitsFile));
-	if (flags == CMPACK_OPEN_CREATE) {
+	if (mode == CMPACK_OPEN_CREATE) {
 		remove(filename);
 		ffdkinit(&fs->fits, filename, &fs->status);
 	} else {
-		readonly = (flags == CMPACK_OPEN_READONLY);
+		readonly = (mode == CMPACK_OPEN_READONLY);
 		ffdkopn(&fs->fits, filename, (readonly ? READONLY : READWRITE), &fs->status);
 	}
 	if (fs->status!=0) {
@@ -465,7 +467,10 @@ int fits_open(tHandle *handle, const char *filename, CmpackOpenMode flags)
 		return CMPACK_ERR_OPEN_ERROR;
 	}
 
-	if (flags != CMPACK_OPEN_CREATE) {
+	fs->mode = mode;
+	fs->flags = flags;
+
+	if (fs->mode != CMPACK_OPEN_CREATE) {
 		ffgiet(fs->fits, &imgtype, &fs->status);
 		switch (imgtype)
 		{
@@ -888,7 +893,7 @@ char *fits_getobslon(tHandle handle)
 		}
     }
 	if (status==0 && *lonstr!='\0') {
-		if (cmpack_strtolon(lonstr, &val) == 0) {
+		if (fits_strtolon(fs, lonstr, &val)) {
 			if (strstr(commstr, "hours"))
 				val *= 15.0;
 			cmpack_lontostr(val, buf, 256);
@@ -1342,3 +1347,10 @@ int fits_getwcs(tHandle handle, CmpackWcs **wcs)
 	}
 	return 0;
 }
+
+/* Convert string to longiture */
+int fits_strtolon(tHandle handle, const char* str, double* val)
+{
+	CmpackFitsFile* fs = (CmpackFitsFile*)handle;
+	return cmpack_strtolon2(str, (fs->flags & CMPACK_OPENF_POSITIVE_WEST ? 1 : 0), val) == 0;
+}
