@@ -391,7 +391,7 @@ int nef_test(const char *block, size_t length, size_t filesize)
 }
 
 /* Read parameters from SBIG file */
-int nef_open(tHandle *handle, const char *filename, CmpackOpenMode flags)
+int nef_open(tHandle *handle, const char *filename, CmpackOpenMode mode, unsigned flags)
 {
 	int res = 0, intel_format = 0;
 	neffile *raw;
@@ -684,12 +684,13 @@ int nef_copyheader(tHandle fs, CmpackImageHeader *hdr, CmpackChannel channel, Cm
 	/* Set date and time of observation */
 	if (src->date_time) {
 		memset(&dt, 0, sizeof(CmpackDateTime));
-		sscanf(src->date_time, "%4d:%2d:%2d %2d:%2d:%2d", &dt.date.year, &dt.date.month,
-			&dt.date.day, &dt.time.hour, &dt.time.minute, &dt.time.second);
-		sprintf(datestr, "%04d-%02d-%02d", dt.date.year, dt.date.month, dt.date.day);
-		ffpkys(dst,"DATE-OBS", (char*) datestr, "UT DATE OF START",&hdr->status);
-		sprintf(timestr, "%02d:%02d:%02d", dt.time.hour, dt.time.minute, dt.time.second);
-		ffpkys(dst,"TIME-OBS", (char*) timestr, "UT TIME OF START",&hdr->status);
+		if (sscanf(src->date_time, "%4d:%2d:%2d %2d:%2d:%2d", &dt.date.year, &dt.date.month,
+			&dt.date.day, &dt.time.hour, &dt.time.minute, &dt.time.second) == 6) {
+			sprintf(datestr, "%04d-%02d-%02d", dt.date.year, dt.date.month, dt.date.day);
+			ffpkys(dst, "DATE-OBS", (char*)datestr, "UT DATE OF START", &hdr->status);
+			sprintf(timestr, "%02d:%02d:%02d", dt.time.hour, dt.time.minute, dt.time.second);
+			ffpkys(dst, "TIME-OBS", (char*)timestr, "UT TIME OF START", &hdr->status);
+		}
 	}
 
 	/* Other parameters */
@@ -724,9 +725,10 @@ int nef_getdatetime(tHandle handle, CmpackDateTime *dt)
 
 	if (raw->date_time) {
 		memset(dt, 0, sizeof(CmpackDateTime));
-		sscanf(raw->date_time, "%4d:%2d:%2d %2d:%2d:%2d", &dt->date.year, &dt->date.month,
-			&dt->date.day, &dt->time.hour, &dt->time.minute, &dt->time.second);
-		return CMPACK_ERR_OK;
+		if (sscanf(raw->date_time, "%4d:%2d:%2d %2d:%2d:%2d", &dt->date.year, &dt->date.month,
+			&dt->date.day, &dt->time.hour, &dt->time.minute, &dt->time.second) == 6) {
+			return CMPACK_ERR_OK;
+		}
 	}
 	return CMPACK_ERR_KEY_NOT_FOUND;
 }
