@@ -1226,44 +1226,46 @@ void CCatalog::ExportTable(CCSVWriter &writer, unsigned flags, int sort_column_i
 			}
 		}
 
-		if (count>1)
+		if (items && count > 1)
 			SortItems(items, count, type, sort_order);
 
 		// Go through row indices and export them to the file
-		for (int i=0; i<count; i++) {
-			static const int mask = CMPACK_OM_ID | CMPACK_OM_CENTER | CMPACK_OM_MAGNITUDE;
-			if (cmpack_cat_get_star(m_Handle, items[i].row, mask, &obj)==0) {
-				bool show = 1;
-				if (flags & EXPORT_SKIP_INVALID) 
-					show &= (obj.refmag_valid!=0);
-				if (show) {
-					int col = 0;
-					writer.Append();
-					writer.SetInt(col++, obj.id);
-					writer.SetDbl(col++, obj.center_x, 2);
-					writer.SetDbl(col++, obj.center_y, 2);
-					if (Wcs()) {
-						double lng, lat;
-						if (m_Wcs->pixelToWorld(obj.center_x, obj.center_y, lng, lat)) {
-							writer.SetDbl(col, lng, 6);
-							writer.SetDbl(col+1, lat, 6);
+		if (items) {
+			for (int i = 0; i < count; i++) {
+				static const int mask = CMPACK_OM_ID | CMPACK_OM_CENTER | CMPACK_OM_MAGNITUDE;
+				if (cmpack_cat_get_star(m_Handle, items[i].row, mask, &obj) == 0) {
+					bool show = 1;
+					if (flags & EXPORT_SKIP_INVALID)
+						show &= (obj.refmag_valid != 0);
+					if (show) {
+						int col = 0;
+						writer.Append();
+						writer.SetInt(col++, obj.id);
+						writer.SetDbl(col++, obj.center_x, 2);
+						writer.SetDbl(col++, obj.center_y, 2);
+						if (Wcs()) {
+							double lng, lat;
+							if (m_Wcs->pixelToWorld(obj.center_x, obj.center_y, lng, lat)) {
+								writer.SetDbl(col, lng, 6);
+								writer.SetDbl(col + 1, lat, 6);
+							}
+							col += 2;
 						}
-						col+=2;
+						if (obj.refmag_valid)
+							writer.SetDbl(col, obj.refmagnitude, 4);
+						col++;
+						const gchar* cap = selection.Caption(obj.id);
+						if (cap)
+							writer.SetStr(col, cap);
+						col++;
+						const gchar* tag = (tags ? tags->caption(obj.id) : NULL);
+						if (tag)
+							writer.SetStr(col, tag);
 					}
-					if (obj.refmag_valid) 
-						writer.SetDbl(col, obj.refmagnitude, 4);
-					col++;
-					const gchar *cap = selection.Caption(obj.id);
-					if (cap) 
-						writer.SetStr(col, cap);
-					col++;
-					const gchar *tag = (tags ? tags->caption(obj.id) : NULL);
-					if (tag)
-						writer.SetStr(col, tag);
 				}
 			}
+			g_free(items);
 		}
-		g_free(items);
 	}
 }
 
