@@ -132,6 +132,7 @@ CCCDFileDlg::CCCDFileDlg(void):m_File(NULL), m_Image(NULL), m_Wcs(NULL), m_Image
 	m_Rulers = g_Project->GetBool("PreviewDlg", "Rulers");
 	m_Negative = CConfig::GetBool(CConfig::NEGATIVE_CHARTS);
 	m_RowsUpward = CConfig::GetBool(CConfig::ROWS_UPWARD);
+	m_PositiveWest = g_Project->Profile()->GetBool(CProfile::POSITIVE_WEST);
 
 	// Menu bar
 	m_Menu.Create(Menu, false);
@@ -217,7 +218,7 @@ CCCDFileDlg::~CCCDFileDlg()
 bool CCCDFileDlg::LoadFile(GtkWindow *pParent, const char *fpath, GError **error)
 {
 	CCCDFile *file = new CCCDFile();
-	if (!file->Open(fpath, CMPACK_OPEN_READONLY, error)) {
+	if (!file->Open(fpath, CMPACK_OPEN_READONLY, (!m_PositiveWest ? 0 : CMPACK_OPENF_POSITIVE_WEST))) {
 		delete file;
 		return false;
 	}
