@@ -51,9 +51,10 @@ static void DeletePage(tBAAVSSPageData *data, gpointer *user_data)
 static void PrintLocation(const CLocation &loc, char *buf)
 {
 	double lon, lat;
+	int positiveWest = (g_Project->Profile()->GetBool(CProfile::POSITIVE_WEST) ? 1 : 0);
 
 	buf[0] = '\0';
-	if (loc.Valid() && cmpack_strtolon(loc.Lon(), &lon)==0 && cmpack_strtolat(loc.Lat(), &lat)==0) {
+	if (loc.Valid() && cmpack_strtolon2(loc.Lon(), positiveWest, &lon)==0 && cmpack_strtolat(loc.Lat(), &lat)==0) {
 		char buf1[256], buf2[256];
 		if (lat>=-90.0 && lat<=90.0) {
 			if (lat>=0) {
@@ -965,9 +966,10 @@ bool CBaavssExportNextTab::Check()
 {
 	double x, y;
 	char buf[512];
+	int positiveWest = (g_Project->Profile()->GetBool(CProfile::POSITIVE_WEST) ? 1 : 0);
 
 	const gchar *lon = gtk_entry_get_text(GTK_ENTRY(m_Lon));
-	if (strlen(lon)<=0 || cmpack_strtolon(lon, &x)!=0) {
+	if (strlen(lon)<=0 || cmpack_strtolon2(lon, positiveWest, &x)!=0) {
 		ShowError(Window(), "Please, fill in the longitude.");
 		gtk_widget_grab_focus(m_Lon);
 		return false;
