@@ -475,7 +475,7 @@ bool CFrameExportDlg::Execute(const CPhot &file, bool matched, const gchar *name
 	// File types
 	gtk_combo_box_set_model(GTK_COMBO_BOX(m_TypeCombo), NULL);
 	gtk_list_store_clear(m_FileTypes);
-	for (int i=0; FileFormats[i].Caption; i++) {
+	for (int i=0; FileFormats[i].Id != NULL; i++) {
 		GtkTreeIter iter;
 		gtk_list_store_append(m_FileTypes, &iter);
 		gtk_list_store_set(m_FileTypes, &iter, 0, i, 1, FileFormats[i].Caption, -1);
@@ -703,7 +703,7 @@ bool CObjectsExportDlg::Execute(const CSelection &sel, const CTags &tags,
 	// File types
 	gtk_combo_box_set_model(GTK_COMBO_BOX(m_TypeCombo), NULL);
 	gtk_list_store_clear(m_FileTypes);
-	for (int i=0; FileFormats[i].Caption; i++) {
+	for (int i=0; FileFormats[i].Id != NULL; i++) {
 		GtkTreeIter iter;
 		gtk_list_store_append(m_FileTypes, &iter);
 		gtk_list_store_set(m_FileTypes, &iter, 0, i, 1, FileFormats[i].Caption, -1);
@@ -954,22 +954,24 @@ void CPhotObjectsExportDlg::ExportTable(CCSVWriter &writer, tSortColumn sort_col
 			}
 		}
 
-		if (count>1)
+		if (items && count > 1)
 			SortItems(items, count, type, sort_order);
 
-		for (int i=0; i<count; i++) {
-			CmpackPhtObject obj;
-			if (m_File.GetObjectParams(items[i].row, mask, &obj) && obj.ref_id>=0) {
-				writer.Append();
-				writer.SetStr(0, m_Selection.Label(obj.ref_id));
-				writer.SetInt(1, obj.ref_id);
-				writer.SetDbl(2, obj.x, 2);
-				writer.SetDbl(3, obj.y, 2);
-				CmpackPhtData mag;
-				CmpackError code;
-				if (m_File.GetMagnitudeAndCode(items[i].row, mag, code) && mag.mag_valid) 
-					writer.SetDbl(4, mag.magnitude, 4);
-				writer.SetStr(5, m_Tags.caption(obj.id));
+		if (items) {
+			for (int i = 0; i < count; i++) {
+				CmpackPhtObject obj;
+				if (m_File.GetObjectParams(items[i].row, mask, &obj) && obj.ref_id >= 0) {
+					writer.Append();
+					writer.SetStr(0, m_Selection.Label(obj.ref_id));
+					writer.SetInt(1, obj.ref_id);
+					writer.SetDbl(2, obj.x, 2);
+					writer.SetDbl(3, obj.y, 2);
+					CmpackPhtData mag;
+					CmpackError code;
+					if (m_File.GetMagnitudeAndCode(items[i].row, mag, code) && mag.mag_valid)
+						writer.SetDbl(4, mag.magnitude, 4);
+					writer.SetStr(5, m_Tags.caption(obj.id));
+				}
 			}
 		}
 	}
@@ -1065,20 +1067,22 @@ void CCatalogObjectsExportDlg::ExportTable(CCSVWriter &writer, tSortColumn sort_
 			}
 		}
 
-		if (count>1)
+		if (items && count > 1)
 			SortItems(items, count, type, sort_order);
 
-		for (int i=0; i<count; i++) {
-			CmpackCatObject obj;
-			if (m_File.GetObjectParams(items[i].row, mask, &obj)) {
-				writer.Append();
-				writer.SetStr(0, m_Selection.Label(obj.id));
-				writer.SetInt(1, obj.id);
-				writer.SetDbl(2, obj.center_x, 2);
-				writer.SetDbl(3, obj.center_y, 2);
-				if (obj.refmag_valid)
-					writer.SetDbl(4, obj.refmagnitude, 4);
-				writer.SetStr(5, m_Tags.caption(obj.id));
+		if (items) {
+			for (int i = 0; i < count; i++) {
+				CmpackCatObject obj;
+				if (m_File.GetObjectParams(items[i].row, mask, &obj)) {
+					writer.Append();
+					writer.SetStr(0, m_Selection.Label(obj.id));
+					writer.SetInt(1, obj.id);
+					writer.SetDbl(2, obj.center_x, 2);
+					writer.SetDbl(3, obj.center_y, 2);
+					if (obj.refmag_valid)
+						writer.SetDbl(4, obj.refmagnitude, 4);
+					writer.SetStr(5, m_Tags.caption(obj.id));
+				}
 			}
 		}
 	}
