@@ -140,18 +140,20 @@ CDBFReader::CDBFReader(FILE *f):m_File(f), m_Cols(NULL), m_Record(NULL),
 		if (count>0 && count<256) {
 			m_Cols = static_cast<tDBFField*>(malloc(count*sizeof(tDBFField)));
 			m_ColCount = 0;
-			for (int i=0, start=1; i<count; i++) {
-				if (fread(fielddef, sizeof(fielddef), 1, f)==1) {
-					int j = 0;
-					while (j<11 && fielddef[j]!='\0') {
-						m_Cols[m_ColCount].name[j] = fielddef[j];
-						j++;
+			if (m_Cols) {
+				for (int i = 0, start = 1; i < count; i++) {
+					if (fread(fielddef, sizeof(fielddef), 1, f) == 1) {
+						int j = 0;
+						while (j < 11 && fielddef[j] != '\0') {
+							m_Cols[m_ColCount].name[j] = fielddef[j];
+							j++;
+						}
+						m_Cols[m_ColCount].name[j] = '\0';
+						m_Cols[m_ColCount].length = fielddef[16];
+						m_Cols[m_ColCount].start = start;
+						start += fielddef[16];
+						m_ColCount++;
 					}
-					m_Cols[m_ColCount].name[j] = '\0';
-					m_Cols[m_ColCount].length = fielddef[16];
-					m_Cols[m_ColCount].start = start;
-					start += fielddef[16];
-					m_ColCount++;
 				}
 			}
 			fseek(m_File, m_Header.head_len, SEEK_SET);
@@ -322,21 +324,24 @@ char *CCSVFileBase::StrQuote(const char *str, bool quote_always)
 			length++;
 		}
 		char *buf = (char*)malloc((length+1)*sizeof(char));
-		char *dptr = buf;
-		*dptr++ = m_QuoteChar;
-		for (const char *sptr=str; *sptr!='\0'; sptr++) {
-			char ch = (char)(*sptr);
-			if (ch == m_QuoteChar) 
-				*dptr++ = m_QuoteChar;
-			*dptr++ = ch;
+		if (buf) {
+			char* dptr = buf;
+			*dptr++ = m_QuoteChar;
+			for (const char* sptr = str; *sptr != '\0'; sptr++) {
+				char ch = (char)(*sptr);
+				if (ch == m_QuoteChar)
+					*dptr++ = m_QuoteChar;
+				*dptr++ = ch;
+			}
+			*dptr++ = m_QuoteChar;
+			*dptr = '\0';
 		}
-		*dptr++ = m_QuoteChar;
-		*dptr = '\0';
 		return buf;
 	} else {
 		size_t length = strlen(str);
 		char *buf = (char*)malloc((length+1)*sizeof(char));
-		strcpy(buf, str);
+		if (buf)
+			strcpy(buf, str);
 		return buf;
 	}
 }
@@ -391,6 +396,9 @@ char *CCSVFileBase::StrUnquote(const char *str)
 	
 	// Unquote string
 	dptr = buf = (char*)malloc((length+1)*sizeof(char));
+	if (!dptr)
+		return NULL;
+
 	length = state = 0;
 	for (ptr=str; *ptr!='\0'; ptr++) {
 		unsigned char ch = (unsigned char)(*ptr);
@@ -434,15 +442,17 @@ char *CCSVFileBase::StrUnquote(const char *str)
 		}
 	}
 	// For unquoted strings, trim trailing white spaces
-	if (state==3) {
-		dptr--;
-		while (dptr>=buf && *dptr<=' ') {
+	if (dptr) {
+		if (state == 3) {
 			dptr--;
-			length--;
+			while (dptr >= buf && *dptr <= ' ') {
+				dptr--;
+				length--;
+			}
+			dptr++;
 		}
-		dptr++;
+		*dptr = '\0';
 	}
-	*dptr = '\0';
 	return buf;
 }
 
@@ -452,51 +462,60 @@ char *CCSVFileBase::Implode(const tCSVRecord &data, char fieldsep)
 	char *ptr, *buf;
 
 	char **list = (char**)malloc(data.count*sizeof(char*));
-	count = 0;
-	for (i=0; i<data.count; i++) {
-		if (data.list[i]) {
-			list[i] = StrQuote(data.list[i], false);
-			count = i+1;
-		} else 
-		if (m_Header.list[i].defValue) {
-			list[i] = StrQuote(m_Header.list[i].defValue, false);
-			count = i+1;
-		} else {
-			list[i] = NULL;
+	if (list) {
+		memset(list, 0, data.count * sizeof(char*));
+		count = 0;
+		for (i = 0; i < data.count; i++) {
+			if (data.list[i]) {
+				list[i] = StrQuote(data.list[i], false);
+				count = i + 1;
+			}
+			else
+				if (m_Header.list[i].defValue) {
+					list[i] = StrQuote(m_Header.list[i].defValue, false);
+					count = i + 1;
+				}
+				else {
+					list[i] = NULL;
+				}
 		}
-	}
-	size_t length = 1;
-	for (i=0; i<count; i++) {
-		if (length>0)
-			length++;
-		if (list[i])
-			length += strlen(list[i]);
-	}
-	ptr = buf = (char*)malloc((length+1)*sizeof(char));
-	for (i=0; i<count; i++) {
-		if (ptr>buf) 
-			*ptr++ = fieldsep;
-		if (list[i]) {
-			strcpy(ptr, list[i]);
-			ptr += strlen(ptr);
-			free(list[i]);
+		size_t length = 1;
+		for (i = 0; i < count; i++) {
+			if (length > 0)
+				length++;
+			if (list[i])
+				length += strlen(list[i]);
 		}
+		ptr = buf = (char*)malloc((length + 1) * sizeof(char));
+		if (ptr) {
+			for (i = 0; i < count; i++) {
+				if (ptr > buf)
+					*ptr++ = fieldsep;
+				if (list[i]) {
+					strcpy(ptr, list[i]);
+					ptr += strlen(ptr);
+					free(list[i]);
+				}
+			}
+			*ptr = '\0';
+		}
+		free(list);
+		return buf;
 	}
-	*ptr = '\0';
-	free(list);
-	return buf;
+	return NULL;
 }
 
 bool CCSVFileBase::IsValid(const char *buf) const
 {
 	const char *ptr;
-
-	for (ptr=buf; *ptr!='\0'; ptr++) {
-		unsigned char ch = (unsigned char)(*ptr);
-		if (ch=='#')
-			return false;
-		else if (ch==m_FieldSep || ch==m_QuoteChar || ch>' ')
-			return true;
+	if (buf) {
+		for (ptr = buf; *ptr != '\0'; ptr++) {
+			unsigned char ch = (unsigned char)(*ptr);
+			if (ch == '#')
+				return false;
+			else if (ch == m_FieldSep || ch == m_QuoteChar || ch > ' ')
+				return true;
+		}
 	}
 	return false;
 }
@@ -508,68 +527,74 @@ void CCSVFileBase::Explode(const char *str, tCSVRecord &data)
 	data.count = 0;
 	if (str) {
 		buf = (char*)malloc((strlen(str)+1)*sizeof(char));
-		strcpy(buf, str);
-		int state = 0, column = 0;
-		for (ptr=start=buf; *ptr!='\0'; ptr++) {
-			unsigned char ch = (unsigned char)(*ptr);
-			switch (state)
-			{
-			case 0:
-				if (ch=='#') {
-					// Comment line
-					state = 9;
+		if (buf) {
+			strcpy(buf, str);
+			int state = 0, column = 0;
+			for (ptr = start = buf; *ptr != '\0'; ptr++) {
+				unsigned char ch = (unsigned char)(*ptr);
+				switch (state)
+				{
+				case 0:
+					if (ch == '#') {
+						// Comment line
+						state = 9;
+						break;
+					}
+					else if (ch == m_FieldSep) {
+						*ptr = '\0';
+						SetData(data, column++, StrUnquote(start));
+						start = ptr + 1;
+						state = 0;
+					}
+					else if (ch == m_QuoteChar)
+						state = 1;
+					else if (ch > ' ')
+						state = 3;
 					break;
-				} else if (ch==m_FieldSep) {
-					*ptr = '\0';
-					SetData(data, column++, StrUnquote(start));
-					start = ptr+1;
-					state = 0;
-				} else if (ch==m_QuoteChar) 
-					state = 1;
-				else if (ch>' ')
-					state = 3;
-				break;
 
-			case 1:
-				if (ch==m_QuoteChar)
-					state = 2;
-				break;
+				case 1:
+					if (ch == m_QuoteChar)
+						state = 2;
+					break;
 
-			case 2:
-				if (ch==m_FieldSep) {
-					*ptr = '\0';
-					SetData(data, column++, StrUnquote(start));
-					start = ptr+1;
-					state = 0;
-				} else if (ch==m_QuoteChar) {
-					state = 1;
-				} else
-					state = 4;
-				break;
+				case 2:
+					if (ch == m_FieldSep) {
+						*ptr = '\0';
+						SetData(data, column++, StrUnquote(start));
+						start = ptr + 1;
+						state = 0;
+					}
+					else if (ch == m_QuoteChar) {
+						state = 1;
+					}
+					else
+						state = 4;
+					break;
 
-			case 3:
-				if (ch==m_FieldSep) {
-					*ptr = '\0';
-					SetData(data, column++, StrUnquote(start));
-					start = ptr+1;
-					state = 0;
+				case 3:
+					if (ch == m_FieldSep) {
+						*ptr = '\0';
+						SetData(data, column++, StrUnquote(start));
+						start = ptr + 1;
+						state = 0;
+					}
+					break;
+
+				case 4:
+					if (ch == m_FieldSep) {
+						*ptr = '\0';
+						SetData(data, column++, StrUnquote(start));
+						start = ptr + 1;
+						state = 0;
+					}
+					break;
 				}
-				break;
-				
-			case 4:
-				if (ch==m_FieldSep) {
-					*ptr = '\0';
-					SetData(data, column++, StrUnquote(start));
-					start = ptr+1;
-					state = 0;
-				}
-				break;
 			}
+			// Last field
+			if (state == 2 || state == 3)
+				SetData(data, column, StrUnquote(start));
+			free(buf);
 		}
-		// Last field
-		if (state==2 || state==3) 
-			SetData(data, column, StrUnquote(start));
-		free(buf);
 	}
 }
 
