@@ -153,6 +153,8 @@ bool CVarFindDlg::Open(GtkWindow *pParent, bool selected_files, CSelectionList *
 	GtkTreePath *refpath;
 	const gchar *tmp_file;
 
+	bool positiveWest = g_Project->Profile()->GetBool(CProfile::POSITIVE_WEST);
+
 	m_FrameSet.Clear();
 	m_Phot.Clear();
 	m_Frame.Close();
@@ -177,7 +179,7 @@ bool CVarFindDlg::Open(GtkWindow *pParent, bool selected_files, CSelectionList *
 					gchar *fts_file = g_Project->GetImageFile(refpath);
 					if (fts_file) {
 						CCCDFile frame;
-						if (frame.Open(fts_file, CMPACK_OPEN_READONLY, &error)) {
+						if (frame.Open(fts_file, CMPACK_OPEN_READONLY, (!positiveWest ? 0 : CMPACK_OPENF_POSITIVE_WEST), &error)) {
 							m_Image = frame.GetImageData();
 							if (m_Image)
 								m_VarFind.SetImage(m_Image);
@@ -206,7 +208,7 @@ bool CVarFindDlg::Open(GtkWindow *pParent, bool selected_files, CSelectionList *
 				m_VarFind.SetCatalogFile(pParent, &m_Catalog);
 				gchar *fts_file = SetFileExtension(tmp_file, FILE_EXTENSION_FITS);
 				CCCDFile frame;
-				if (frame.Open(fts_file, CMPACK_OPEN_READONLY, &error)) {
+				if (frame.Open(fts_file, CMPACK_OPEN_READONLY, (!positiveWest ? 0 : CMPACK_OPENF_POSITIVE_WEST), &error)) {
 					m_Image = frame.GetImageData();
 					if (m_Image) 
 						m_VarFind.SetImage(m_Image);
@@ -490,7 +492,7 @@ void CVarFindDlg::UpdateLightCurve()
 	m_VarFind.SetLightCurve(CTable());
 	if (objs.CountStars(CMPACK_SELECT_VAR)>0 && objs.CountStars(CMPACK_SELECT_COMP)>0 && apertureId>=0) {
 		GError *error = NULL;
-		CTable *lcurve = CmpackLightCurve(NULL, m_FrameSet, apertureId, objs, CObjectCoords(), CLocation(), CMPACK_LCURVE_FRAME_IDS, &error);
+		CTable *lcurve = CmpackLightCurve(NULL, m_FrameSet, *g_Project->Profile(), apertureId, objs, CObjectCoords(), CLocation(), CMPACK_LCURVE_FRAME_IDS, &error);
 		if (lcurve) {
 			m_VarFind.SetLightCurve(*lcurve);
 			delete lcurve;
