@@ -109,10 +109,12 @@ CImage::~CImage()
 //
 // Load image info from a CCD file
 //
-CImage *CImage::fromFile(const gchar *fpath, CmpackBitpix bitpix, GError **error)
+CImage *CImage::fromFile(const gchar *fpath, const CProfile* profile, CmpackBitpix bitpix, GError **error)
 {
+	bool positiveWest = (profile ? profile->GetBool(CProfile::POSITIVE_WEST) : CConfig::GetBool(CConfig::POSITIVE_WEST));
+
 	CCCDFile f;
-	if (f.Open(fpath, CMPACK_OPEN_READONLY, error)) 
+	if (f.Open(fpath, CMPACK_OPEN_READONLY, (!positiveWest ? 0 : CMPACK_OPENF_POSITIVE_WEST), error))
 		return f.GetImageData(bitpix, error);
 	return NULL;
 }
