@@ -651,7 +651,7 @@ void CMatchingSTTab::UpdatePreview(bool force_update)
 				} else 
 				if (state & CFILE_CONVERSION) {
 					gchar *fts_file = g_Project->GetImageFile(path);
-					CImage *img = CImage::fromFile(fts_file);
+					CImage *img = CImage::fromFile(fts_file, g_Project->Profile());
 					if (img) {
 						UpdateImage(img);
 						delete img;
@@ -659,7 +659,7 @@ void CMatchingSTTab::UpdatePreview(bool force_update)
 					g_free(fts_file);
 				} else {
 					gchar *src_file = g_Project->GetSourceFile(path);
-					CImage *img = CImage::fromFile(src_file);
+					CImage *img = CImage::fromFile(src_file, g_Project->Profile());
 					if (img) {
 						UpdateImage(img);
 						delete img;
@@ -708,7 +708,7 @@ void CMatchingSTTab::UpdatePreview(bool force_update)
 					UpdateChart(cat);
 				if (m_DMCatalog == DISPLAY_IMAGE) {
 					gchar *fts_file = SetFileExtension(m_CatFile, FILE_EXTENSION_FITS);
-					CImage *img = CImage::fromFile(fts_file);
+					CImage *img = CImage::fromFile(fts_file, g_Project->Profile());
 					if (img) {
 						UpdateImage(img);
 						delete img;
