@@ -26,6 +26,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "profile_editor.h"
 #include "observer_dlg.h"
 #include "main.h"
+#include "configuration.h"
 
 // Options for image rotation
 static const CEditProfileBase::tStringList BitpixStrings[] = {
@@ -50,6 +51,13 @@ static const CEditProfileBase::tStringList BinningStrings[] = {
 	{ NULL }
 };
 
+// Longitude direction
+static const CEditProfileBase::tStringList LongitudeStrings[] = {
+	{ "East of Greenwich meridian",	0 },
+	{ "West of Greenwich meridian",	1 },
+	{ NULL }
+};
+
 static int binning_to_index(int binning)
 {
 	for (int i=0; BinningStrings[i].str!=NULL; i++) {
@@ -274,10 +282,14 @@ void CEditProfileBase::CreatePages(GSList **stack)
 	m_BBottom = add_spin_button(GTK_TABLE(tbox2), 4, 1, imin, imax, 1, 0, "Number of unused pixels at the bottom of each frame");
 	gtk_table_attach(GTK_TABLE(tbox2), new_label("", TRUE), 6, 7, 1, 2, 
 		GtkAttachOptions(GTK_FILL | GTK_EXPAND), GTK_FILL, 0, 0);
-	add_label(GTK_TABLE(tbox2), 6, "Add constant offset to the time of observation:");
-	m_TimeOffset = add_spin_button_int(GTK_TABLE(tbox2), 7, "Time offset", 
+	add_label(GTK_TABLE(tbox2), 3, "Add constant offset to the time of observation:");
+	m_TimeOffset = add_spin_button_int(GTK_TABLE(tbox2), 4, "Time offset", 
 		CProfile::TIME_OFFSET, 1, "Time offset in seconds that will be always added to the time of observation saved in source frames.");
 
+	add_label(GTK_TABLE(tbox), 6, "<b>Regional settings</b>");
+	m_LongitudeDir = add_combo_box(GTK_TABLE(tbox), 8, "Positive longitude is:", 
+		LongitudeStrings, "Interpretation of positive values of longitude in source FITS files.");
+
 	// Calibration
 	tbox = CreatePage(PAGE_CALIBRATION, 1, "Calibration", NULL, TRUE, stack);
 	add_label(GTK_TABLE(tbox), 0, "<b>Calibration scheme</b>");
@@ -561,6 +573,8 @@ void CEditProfileBase::SetData(void)
 		m_Profile.GetBool(CProfile::FLIP_V));
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(m_TimeOffset), 
 		m_Profile.GetInt(CProfile::TIME_OFFSET));
+	gtk_combo_box_set_active(GTK_COMBO_BOX(m_LongitudeDir),
+		m_Profile.GetBool(CProfile::POSITIVE_WEST) ? 1 : 0);
 	gtk_widget_set_sensitive(m_DataMin, editable);
 	gtk_widget_set_sensitive(m_DataMax, editable);
 	gtk_widget_set_sensitive(m_WorkFormat, editable);
@@ -568,6 +582,7 @@ void CEditProfileBase::SetData(void)
 	gtk_widget_set_sensitive(m_FlipH, editable);
 	gtk_widget_set_sensitive(m_FlipV, editable);
 	gtk_widget_set_sensitive(m_TimeOffset, editable);
+	gtk_widget_set_sensitive(m_LongitudeDir, editable);
 	CmpackBorder border(m_Profile.GetBorder());
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(m_BLeft), border.left);
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(m_BRight), border.right);
@@ -703,6 +718,8 @@ void CEditProfileBase::GetData(void)
 		gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(m_FlipV))!=FALSE);
 	m_Profile.SetInt(CProfile::TIME_OFFSET, 
 		(gint)gtk_spin_button_get_value(GTK_SPIN_BUTTON(m_TimeOffset)));
+	m_Profile.SetBool(CProfile::POSITIVE_WEST,
+		gtk_combo_box_get_active(GTK_COMBO_BOX(m_LongitudeDir)) != 0);
 	CmpackBorder border;
 	border.left = (gint)gtk_spin_button_get_value(GTK_SPIN_BUTTON(m_BLeft));
 	border.right = (gint)gtk_spin_button_get_value(GTK_SPIN_BUTTON(m_BRight));
@@ -797,7 +814,8 @@ bool CEditProfileBase::CheckPage(tProfilePageId id, GError **error)
 		if (*lon!='\0' || *lat!='\0') {
 			char buf[64];
 			double x, y;
-			if (cmpack_strtolon(lon, &x)!=0) {
+			int positiveWest = (g_Project->Profile()->GetBool(CProfile::POSITIVE_WEST) ? 1 : 0);
+			if (cmpack_strtolon2(lon, positiveWest, &x)!=0) {
 				g_set_error(error, g_AppError, PAGE_OBSERVER, "Invalid value of the longitude");
 				return false;
 			}
@@ -891,6 +909,8 @@ void CEditProfileBase::OnSetDefaultsClicked(GtkWidget *pButton)
 		gtk_spin_button_set_value(GTK_SPIN_BUTTON(m_BRight), 0);
 		gtk_spin_button_set_value(GTK_SPIN_BUTTON(m_BTop), 0);
 		gtk_spin_button_set_value(GTK_SPIN_BUTTON(m_BBottom), 0);
+		gtk_combo_box_set_active(GTK_COMBO_BOX(m_LongitudeDir),
+			CConfig::GetBool(CConfig::POSITIVE_WEST) ? 1 : 0);
 		break;
 
 	case PAGE_CALIBRATION:
