@@ -252,9 +252,7 @@ bool CNewProjectDlg::OnCloseQuery(void)
 {
 	char buf[256];
 	GtkTreeModel *model;
-	gchar *profile;
 	GtkTreeIter iter;
-	gboolean userDefined;
 
 	g_free(m_FilePath);
 	m_FilePath = NULL;
@@ -280,6 +278,8 @@ bool CNewProjectDlg::OnCloseQuery(void)
 	}
 
 	// Profile
+	gchar* profile = NULL;
+	gboolean userDefined = false;
 	GtkTreeSelection *selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(m_TreeView));
 	if (gtk_tree_selection_get_selected(selection, &model, &iter)) 
 		gtk_tree_model_get(model, &iter, TCOL_FILEPATH, &profile, TCOL_USERDEFINED, &userDefined, -1);
@@ -308,6 +308,9 @@ bool CNewProjectDlg::OnCloseQuery(void)
 		CConfig::SetStr("NewProject", "LastProfile", profile);
 		g_free(profile);
 	}
+
+	// Override profile settings that are stored in the Environment, not in saved or default profiles.
+	m_Profile.SetBool(CProfile::POSITIVE_WEST, CConfig::GetBool(CConfig::POSITIVE_WEST));
 	
 	// Check that the selected parent directory exists
 	if (!g_file_test(m_ParentDir, G_FILE_TEST_IS_DIR)) {
@@ -959,7 +962,9 @@ void CImportProject2Dlg::ChangeDirPath(void)
 
 //-------------------------   EDIT PROJECT WIDGET   ------------------------------
 
-CEditProject::CEditProject(CEditProjectDlg *pParent):m_pParent(pParent), m_ProjectType(EndOfProjectTypes)
+CEditProject::CEditProject(CEditProjectDlg *pParent):m_pParent(pParent), m_ProjectType(EndOfProjectTypes), m_Bias(NULL),
+	m_Cat(NULL), m_Dark(NULL), m_Flat(NULL), m_LoadFromProfile(NULL), m_LoadFromProject(NULL), m_SaveAsProfile(NULL), 
+	m_Name(NULL), m_Path(NULL), m_Ref(NULL), m_Rename(NULL), m_Type(NULL), m_TypeBtn(NULL)
 {
 	gchar *str = CConfig::GetStr("ProjectDlg", "LastPage");
 	SetInitialPage(str_to_page(str, PAGE_PROJECT));
